@@ -11,15 +11,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -48,6 +45,7 @@ __all__ = (
     "PortMappingTypeDef",
     "ProgressDetailTypeDef",
     "RenderingEngineTypeDef",
+    "ResponseMetadata",
     "RobotApplicationConfigTypeDef",
     "RobotApplicationSummaryTypeDef",
     "RobotDeploymentTypeDef",
@@ -349,6 +347,17 @@ RenderingEngineTypeDef = TypedDict(
     "RenderingEngineTypeDef", {"name": Literal["OGRE"], "version": str}, total=False
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredRobotApplicationConfigTypeDef = TypedDict(
     "_RequiredRobotApplicationConfigTypeDef",
     {"application": str, "launchConfig": "LaunchConfigTypeDef"},
@@ -449,7 +458,11 @@ RobotTypeDef = TypedDict(
     total=False,
 )
 
-S3KeyOutputTypeDef = TypedDict("S3KeyOutputTypeDef", {"s3Key": str, "etag": str}, total=False)
+S3KeyOutputTypeDef = TypedDict(
+    "S3KeyOutputTypeDef",
+    {"s3Key": str, "etag": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
 
 _RequiredS3ObjectTypeDef = TypedDict("_RequiredS3ObjectTypeDef", {"bucket": str, "key": str})
 _OptionalS3ObjectTypeDef = TypedDict("_OptionalS3ObjectTypeDef", {"etag": str}, total=False)
